{
  pkgs,
  lib,
  ...
}:

{
  environment.systemPackages =
    let
      # https://wiki.nixos.org/wiki/TexLive
      # minimal set of latex packages for orgmode
      # emacs config:
      # (setq org-latex-complier "lualatex")
      # (setq org-preview-latex-default-process 'dvisvgm)
      orgmode-tex = (
        pkgs.texlive.combine {
          inherit (pkgs.texlive)
            scheme-basic
            dvisvgm
            dvipng
            wrapfig
            amsmath
            ulem
            hyperref
            capt-of
            ;
        }
      );
    in
    with pkgs;
    [
      mu
      orgmode-tex
    ];

  services.emacs = {
    install = true;
    enable = true;
    package =
      with pkgs;
      (
        (emacsPackagesFor (
          emacs-pgtk.overrideAttrs (old: {
            passthru = old.passthru // {
              treeSitter = true;
            };
          })
        )).emacsWithPackages
        (
          epkgs: with epkgs; [
            treesit-grammars.with-all-grammars
            vterm
            pdf-tools
            mu4e
          ]
        )
      );
    defaultEditor = lib.mkForce true;
  };
}
